Class: Object

Inherits:
BasicObject
Defined in:
lib/sparql/algebra/extensions.rb

Overview

Extensions for Ruby’s Object class.

Instance Method Summary collapse

Instance Method Details

#to_sseObject

Make sure the object is in SXP form and transform it to a string form

Returns:

  • String



17
18
19
# File 'lib/sparql/algebra/extensions.rb', line 17

def to_sse
  SXP::Generator.string(self.to_sxp_bin)
end

#to_sxp_binString

Returns the SXP binary representation of this object, defaults to self.

Returns:

  • (String)


10
11
12
# File 'lib/sparql/algebra/extensions.rb', line 10

def to_sxp_bin
  self
end